@@ -22,11 +22,18 @@ class MotorEnginePlugin(BasePlugin):
                 db=value['database'],
                 host=value['host'],
                 port=int(value['port']),
-                #username=value.get('username', None),
-                #password=value.get('password', None),
                 io_loop=io_loop
             )
 
+            username = value.get('username', None)
+            password = value.get('password', None)
+
+            if username is not None:
+                arguments['username'] = username
+
+            if password is not None:
+                arguments['password'] = password
+
             arguments['alias'] = key
 
             replica_set = arguments.get('replica_set', None)
